==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/General/rdetect/translations/rdetect_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Estensione rilevamento volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Informazioni sull&apos;estensione rilevamento volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Estensione rilevamento del volume rimovibile per Qmmp</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Estensione che permette il rilevamento del volume rimovibile</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Aggiungi CD «%1»</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Aggiungi volume «%1»</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Impostazioni dell&apos;estensione di rilevamento del volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Rilevamento CD Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Aggiungi automaticamente le tracce alla scaletta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Rimuovi automaticamente i titoli dalla scaletta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Rilevamento dispositivi rimovibili</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Aggiungi automaticamente i file alla scaletta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Rimuovi automaticamente i file dalla scaletta</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/General/rdetect/translations/rdetect_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Estensione rilevamento volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Informazioni sull&apos;estensione rilevamento volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Estensione rilevamento del volume rimovibile per Qmmp</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Estensione che permette il rilevamento del volume rimovibile</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RDetectSettingsDialog</name>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Impostazioni dell&apos;estensione di rilevamento del volume</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Rilevamento CD Audio</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Aggiungi automaticamente le tracce alla scaletta</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Rimuovi automaticamente i titoli dalla scaletta</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Rilevamento dispositivi rimovibili</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Aggiungi automaticamente i file alla scaletta</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Rimuovi automaticamente i file dalla scaletta</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Aggiungi CD «%1»</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Aggiungi volume «%1»</translation>
    </message>
</context>
</TS>
